@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import IO, Any, Dict, List, Union
+from typing import IO, Any, Dict, List, Mapping, Sequence, Union
 
 from botocore.response import StreamingBody
 
@@ -214,7 +214,7 @@ CachingConfigTypeDef = TypedDict(
     "CachingConfigTypeDef",
     {
         "ttl": int,
-        "cachingKeys": List[str],
+        "cachingKeys": Sequence[str],
     },
     total=False,
 )
@@ -389,8 +389,8 @@ _OptionalCreateGraphqlApiRequestRequestTypeDef = TypedDict(
         "logConfig": "LogConfigTypeDef",
         "userPoolConfig": "UserPoolConfigTypeDef",
         "openIDConnectConfig": "OpenIDConnectConfigTypeDef",
-        "tags": Dict[str, str],
-        "additionalAuthenticationProviders": List["AdditionalAuthenticationProviderTypeDef"],
+        "tags": Mapping[str, str],
+        "additionalAuthenticationProviders": Sequence["AdditionalAuthenticationProviderTypeDef"],
         "xrayEnabled": bool,
         "lambdaAuthorizerConfig": "LambdaAuthorizerConfigTypeDef",
     },
@@ -1091,7 +1091,7 @@ PaginatorConfigTypeDef = TypedDict(
 PipelineConfigTypeDef = TypedDict(
     "PipelineConfigTypeDef",
     {
-        "functions": List[str],
+        "functions": Sequence[str],
     },
     total=False,
 )
@@ -1175,7 +1175,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
 )
 
@@ -1195,7 +1195,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tagKeys": List[str],
+        "tagKeys": Sequence[str],
     },
 )
 
@@ -1335,7 +1335,7 @@ _OptionalUpdateGraphqlApiRequestRequestTypeDef = TypedDict(
         "authenticationType": AuthenticationTypeType,
         "userPoolConfig": "UserPoolConfigTypeDef",
         "openIDConnectConfig": "OpenIDConnectConfigTypeDef",
-        "additionalAuthenticationProviders": List["AdditionalAuthenticationProviderTypeDef"],
+        "additionalAuthenticationProviders": Sequence["AdditionalAuthenticationProviderTypeDef"],
         "xrayEnabled": bool,
         "lambdaAuthorizerConfig": "LambdaAuthorizerConfigTypeDef",
     },
